@@ -146,7 +146,36 @@ public class TimeBasedRollingWithConfigFileTest extends ScaffoldingForRollingTes
 
         statusChecker.assertContainsMatch("Missing integer token");
         assertFalse(rfa.isStarted());
+    }
 
+
+    // see also LOGBACK-1176
+    @Test
+    public void timeAndSizeWithoutMaxFileSize() throws Exception {
+        String testId = "timeAndSizeWithoutMaxFileSize";
+        loadConfig(ClassicTestConstants.JORAN_INPUT_PREFIX + "rolling/" + testId + ".xml");
+        Logger root = lc.getLogger(Logger.ROOT_LOGGER_NAME);
+        //expectedFilenameList.add(randomOutputDir + "z" + testId);
+        RollingFileAppender<ILoggingEvent> rfa = (RollingFileAppender<ILoggingEvent>) root.getAppender("ROLLING");
+      
+
+        //statusChecker.assertContainsMatch("Missing integer token");
+        assertFalse(rfa.isStarted());
+        StatusPrinter.print(lc);
+    }
+
+    @Test
+    public void totalSizeCapSmallerThanMaxFileSize() throws Exception {
+        String testId = "totalSizeCapSmallerThanMaxFileSize";
+        lc.putProperty("testId", testId);
+        loadConfig(ClassicTestConstants.JORAN_INPUT_PREFIX + "rolling/" + testId + ".xml");
+        Logger root = lc.getLogger(Logger.ROOT_LOGGER_NAME);
+        //expectedFilenameList.add(randomOutputDir + "z" + testId);
+        RollingFileAppender<ILoggingEvent> rfa = (RollingFileAppender<ILoggingEvent>) root.getAppender("ROLLING");
+      
+        statusChecker.assertContainsMatch("totalSizeCap of \\[\\d* \\w*\\] is smaller than maxFileSize \\[\\d* \\w*\\] which is non-sensical");
+        assertFalse(rfa.isStarted());
+      
     }
 
     void addExpectedFileNamedIfItsTime(String testId, String msg, boolean gzExtension) {
